/*
GNU General Public License

FilterDemo
Copyright (C) 2000  Howard A Kistler

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

package com.hexidec.filter;

import java.awt.*;
import java.awt.Color;
import java.awt.Frame;
import java.awt.Graphics;
import java.awt.Image;
import java.awt.MediaTracker;
import java.awt.Toolkit;
import java.awt.image.FilteredImageSource;
import java.awt.image.ImageFilter;
import java.awt.image.ImageProducer;
import java.awt.image.RGBImageFilter;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;

import com.hexidec.filter.*;

/** FilterDemo
  * Demonstrates the various filters
  *
  * @author Howard Kistler
  * @version 0.1
  *
  * REQUIREMENTS
  * Java 2 (JDK 1.3)
  *
  * VERSION HISTORY
  * 0.1 (01/24/2001) - initial creation (01/24/2001)
  */

public class FilterDemo extends Frame
{

	Image baseImage;
	Image imageGrey = null;
	Image imageColorize = null;
	Image imageInverse = null;
	Image imageMonoHigh = null;
	Image imageMonoMed  = null;
	Image imageMonoLow  = null;

//  Constructors ---------------------------------------------------------------------------->

	public FilterDemo(String imageFile)
	{
		super("Filter Demo");

		this.addWindowListener(
			new WindowAdapter()
			{
				public void windowClosing(WindowEvent we)
				{
					System.exit(0);
				}
			}
		);

		// load Image
		MediaTracker mt = new MediaTracker(this);
		baseImage = Toolkit.getDefaultToolkit().getImage(imageFile);
		mt.addImage(baseImage, 1);
		try
		{
			mt.waitForID(1);
		}
		catch(InterruptedException ie)
		{
			baseImage = null;
			System.out.println("Error loading image " + imageFile + " - " + ie.getMessage());
		}
		if(baseImage != null)
		{
			RGBGreyscaleFilter rgbGreyscale = new RGBGreyscaleFilter();
			imageGrey = rgbGreyscale.procImage(baseImage);
			RGBColorizeFilter rgbColorize = new RGBColorizeFilter(new Color(255, 255, 0));
			imageColorize = rgbColorize.procImage(baseImage);
			RGBInverseFilter rgbInverse = new RGBInverseFilter();
			imageInverse = rgbInverse.procImage(baseImage);
			RGBMonochromeFilter rgbMonochrome1 = new RGBMonochromeFilter(128);
			imageMonoMed = rgbMonochrome1.procImage(baseImage);
			RGBMonochromeFilter rgbMonochrome2 = new RGBMonochromeFilter(192);
			imageMonoHigh = rgbMonochrome2.procImage(baseImage);
			RGBMonochromeFilter rgbMonochrome3 = new RGBMonochromeFilter(64);
			imageMonoLow = rgbMonochrome3.procImage(baseImage);
		}
		this.setSize(300, 100);
	}

// Paint Method ------------------------------------------------------------------------------>

	public void paint(Graphics g)
	{
		super.paint(g);
		int xOffset = 32;
		int xStep   = xOffset;
		if(baseImage != null) {
			xOffset = baseImage.getWidth(this);
			xStep   = xOffset;
		}
		if(baseImage != null)     { g.drawImage(baseImage,     xOffset, xStep, this); xOffset += xStep + 1; }
		if(imageGrey != null)     { g.drawImage(imageGrey,     xOffset, xStep, this); xOffset += xStep + 1; }
		if(imageColorize != null) { g.drawImage(imageColorize, xOffset, xStep, this); xOffset += xStep + 1; }
		if(imageInverse != null)  { g.drawImage(imageInverse,  xOffset, xStep, this); xOffset += xStep + 1; }
		if(imageMonoHigh != null) { g.drawImage(imageMonoHigh, xOffset, xStep, this); xOffset += xStep + 1; }
		if(imageMonoMed != null)  { g.drawImage(imageMonoMed,  xOffset, xStep, this); xOffset += xStep + 1; }
		if(imageMonoLow != null)  { g.drawImage(imageMonoLow,  xOffset, xStep, this); xOffset += xStep + 1; }
	}

//  Main Method ----------------------------------------------------------------------------->

	public static void main(String[] args)
	{
		if(args.length > 0)
		{
			FilterDemo fd = new FilterDemo(args[0]);
			fd.show();
		}
		else
		{
			System.out.println("You must specify an image name");
		}
	}

}
