/*
GNU General Public License

RGBGreyscaleFilter
Copyright (C) 2000  Howard A Kistler

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

package com.hexidec.filter;

import java.awt.Color;
import java.awt.Image;
import java.awt.Toolkit;
import java.awt.image.FilteredImageSource;
import java.awt.image.ImageFilter;
import java.awt.image.ImageProducer;
import java.awt.image.RGBImageFilter;

/** RGBGreyscaleFilter
  * Creates a greyscale version of an image
  *
  * @author Howard Kistler
  * @version 0.1
  *
  * REQUIREMENTS
  * Java 2 (JDK 1.3)
  *
  * VERSION HISTORY
  * 0.1 (10/31/2000) - initial creation (10/31/2000)
  */

public class RGBGreyscaleFilter extends RGBImageFilter
{

//  Constructors ---------------------------------------------------------------------------->

	public RGBGreyscaleFilter()
	{
		canFilterIndexColorModel = true;
	}

//  Image Processing Methods ---------------------------------------------------------------->

	/** Modify and return a greyscale version of the image
	  */
	public Image procImage(Image source)
	{
		ImageProducer imageProducer = new FilteredImageSource(source.getSource(), this);
		Image recoloredImage = Toolkit.getDefaultToolkit().createImage(imageProducer);
		return recoloredImage;
	}

//  Image Filtering Method ------------------------------------------------------------------>

	/** Called by the filter upon each pixel to determine its greyscale equivalent
	  * Conversion formula -> AVG(r & g & b)
	  */
	public int filterRGB(int x, int y, int rgb)
	{
		int alpha = (rgb >> 24) & 0xFF;
		int red   = (rgb >> 16) & 0xFF;
		int green = (rgb >>  8) & 0xFF;
		int blue  = (rgb      ) & 0xFF;
		/*
		// Conversion formula -> luminance = .299 red + .587 green + .114 blue (luminance results are flakey)
		float rGrey = 0.299f * (red   / 255);
		float gGrey = 0.587f * (green / 255);
		float bGrey = 0.114f * (blue  / 255);
		float luminance = rGrey + gGrey + bGrey;
		if(luminance > 1.0f) { luminance = 1.0f; }
		*/
		int brightness = (int)((red + green + blue) / 3);
		Color grey = new Color(brightness, brightness, brightness);
		rgb = grey.getRGB();
		return (rgb & 0x00FFFFFF) | (alpha << 24);
	}

}
