/*
GNU General Public License

RGBMonochromeFilter
Copyright (C) 2000  Howard A Kistler

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

package com.hexidec.filter;

import java.awt.Color;
import java.awt.Image;
import java.awt.Toolkit;
import java.awt.image.FilteredImageSource;
import java.awt.image.ImageFilter;
import java.awt.image.ImageProducer;
import java.awt.image.RGBImageFilter;

/** RGBMonochromeFilter
  * Creates a black-and-white version of an image
  *
  * @author Howard Kistler
  * @version 0.1
  *
  * REQUIREMENTS
  * Java 2 (JDK 1.3)
  *
  * VERSION HISTORY
  * 0.1 (01/24/2001) - initial creation (01/24/2001)
  */

public class RGBMonochromeFilter extends RGBImageFilter
{

	private int threshold;
	private int mWhite = (new Color(255, 255, 255)).getRGB();
	private int mBlack = (new Color(0, 0, 0)).getRGB();

//  Constructors ---------------------------------------------------------------------------->

	public RGBMonochromeFilter(int threshold)
	{
		this.threshold = threshold;
		canFilterIndexColorModel = true;
	}

	public RGBMonochromeFilter()
	{
		this(128);
	}

//  Accessor Methods ------------------------------------------------------------------------>

	public int getThreshold()               { return threshold; }
	public void setThreshold(int threshold) { this.threshold = threshold; }

//  Image Processing Methods ---------------------------------------------------------------->

	/** Modify and return a monochrome version of the image
	  */
	public Image procImage(Image source, int threshold)
	{
		ImageProducer imageProducer = new FilteredImageSource(source.getSource(), this);
		Image recoloredImage = Toolkit.getDefaultToolkit().createImage(imageProducer);
		return recoloredImage;
	}

	public Image procImage(Image source)
	{
		return procImage(source, threshold);
	}

//  Image Filtering Method ------------------------------------------------------------------>

	/** Called by the filter upon each pixel to determine its greyscale equivalent
	  * Conversion formula -> AVG(r & g & b) > threshold = white, else = black
	  */
	public int filterRGB(int x, int y, int rgb)
	{
		int alpha = (rgb >> 24) & 0xFF;
		int red   = (rgb >> 16) & 0xFF;
		int green = (rgb >>  8) & 0xFF;
		int blue  = (rgb      ) & 0xFF;
		int brightness = (int)((red + green + blue) / 3);
		if(brightness > threshold) { rgb = mWhite; }
		else                       { rgb = mBlack; }
		return (rgb & 0x00FFFFFF) | (alpha << 24);
	}

}
