/*
GNU General Public License

RGBReplaceFilter
Copyright (C) 2000  Howard A Kistler

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

package com.hexidec.filter;

import java.awt.Color;
import java.awt.Image;
import java.awt.Toolkit;
import java.awt.image.FilteredImageSource;
import java.awt.image.ImageFilter;
import java.awt.image.ImageProducer;
import java.awt.image.RGBImageFilter;
import java.util.Hashtable;

/** RGBReplaceFilter
  * Changes an image by replacing each color in the key position
  * with the corresponding color from the value position
  *
  * @author Howard Kistler
  * @version 0.1
  *
  * REQUIREMENTS
  * Java 2 (JDK 1.3)
  *
  * VERSION HISTORY
  * 0.1 (10/31/2000) - initial creation (10/31/2000)
  */

public class RGBReplaceFilter extends RGBImageFilter
{

//  Collections ----------------------------------------------------------------------------->

	private Hashtable htNewColors; // a Hashtable of color keys (rXXXgXXXbXXX) & replacement Color values

//  Constructors ---------------------------------------------------------------------------->

	public RGBReplaceFilter(Hashtable htNC)
	{
		canFilterIndexColorModel = true;
		htNewColors = htNC;
	}

	public RGBReplaceFilter()
	{
		this(new Hashtable());
	}

//  Accessor Method ------------------------------------------------------------------------->

	/* Set the replacement color lookup table */
	public void setNewColors(Hashtable ht)
	{
		htNewColors  = ht;
	}

//  Image Processing Methods ---------------------------------------------------------------->

	/** Modify and return an image with this filter using the specified recolor table
	  */
	public Image procImage(Image source, Hashtable htNC)
	{
		htNewColors = htNC;
		return procImage(source);
	}

	/** Modify and return an image with this filter
	  */
	public Image procImage(Image source)
	{
		ImageProducer imageProducer = new FilteredImageSource(source.getSource(), this);
		Image recoloredImage = Toolkit.getDefaultToolkit().createImage(imageProducer);
		return recoloredImage;
	}

//  Image Filtering Method ------------------------------------------------------------------>

	/** Called by the filter upon each pixel to determine its modified color
	  */
	public int filterRGB(int x, int y, int rgb)
	{
		int alpha = (rgb >> 24) & 0xff;
		int red   = (rgb >> 16) & 0xff;
		int green = (rgb >>  8) & 0xff;
		int blue  = (rgb      ) & 0xff;
		String key = "r" + red + "g" + green + "b" + blue;
		if(htNewColors.containsKey(key))
		{
			Color lookupColor = (Color)(htNewColors.get(key));
			return (lookupColor.getRGB() & 0x00FFFFFF) | (alpha << 24);
		}
		return rgb;
	}

}
